@@ -1,5 +1,5 @@
 # /// script
-# requires-python = ">=3.14"
+# requires-python = ">=3.12"
 # dependencies = [
 #     "nest-asyncio2",
 # ]
@@ -7,6 +7,9 @@
 # [tool.uv.sources]
 # nest-asyncio2 = { path = "../", editable = true }
 # ///
+import warnings
+warnings.filterwarnings("default")
+
 import asyncio
 import nest_asyncio2
 
